@@ -692,7 +692,6 @@ void NetworkPanel::passwordError(const QString &dev, const QString &ssid)
     if (!ssid.isEmpty()) {
         m_reconnectSsid = ssid;
         m_reconnectDev = dev;
-        m_waitPassword = true;
         clear();
     }
     if (!m_reconnectSsid.isEmpty()) {
@@ -700,14 +699,9 @@ void NetworkPanel::passwordError(const QString &dev, const QString &ssid)
     }
 }
 
-bool NetworkPanel::changePassword(const QString &key, const QString &password, bool input)
+void NetworkPanel::changePassword(const QString &key, const QString &password, bool input)
 {
-    if (m_waitPassword) {
-        Q_EMIT passwordChanged(key,password,input);
-        m_waitPassword = false;
-        return true;
-    }
-    return false;
+    Q_EMIT passwordChanged(key,password,input);
 }
 
 QString NetworkPanel::ssidWaitingForPassword() const
@@ -1061,7 +1055,7 @@ void NetworkDelegate::drawRefreshButton(QPainter *painter, const QStyleOptionVie
         return;
 
     QRect rctIcon(option.rect.width() - SWITCH_WIDTH - 36, option.rect.top() + (option.rect.height() - 20) / 2, 20, 20);
-    QPixmap pixmap = DHiDPIHelper::loadNxPixmap(ThemeManager::instance()->getIcon("wireless/refresh"));
+    QPixmap pixmap = DHiDPIHelper::loadNxPixmap(ThemeManager::instance()->getIcon("refresh"));
     painter->save();
     painter->setRenderHint(QPainter::Antialiasing, true);
     if (m_refreshAngle.contains(index)) {
