@@ -842,6 +842,22 @@
         <source>Port</source>
         <translation>Porta</translation>
     </message>
+    <message>
+        <source>Authentication is required</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Required</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>HTTP Proxy</source>
         <translation>Proxy HTTP</translation>
