@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
 <context>
     <name>Bubble</name>
     <message>
@@ -6,6 +6,17 @@
         <translation>1 nova mensagem</translation>
     </message>
 </context>
+<context>
+    <name>DeviceControllItem</name>
+    <message>
+        <source>Wireless Network</source>
+        <translation>Rede sem fios</translation>
+    </message>
+    <message>
+        <source>Wired Network</source>
+        <translation>Rede por cabo</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -42,10 +53,28 @@
     </message>
 </context>
 <context>
-    <name>dss::module::NetworkModule</name>
+    <name>WirelessItem</name>
     <message>
-        <source>Wired Connection</source>
-        <translation>Ligação por cabo</translation>
+        <source>Connect to hidden network</source>
+        <translation>Ligar a uma rede oculta</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Palavra-passe</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <source>Connect</source>
+        <comment>button</comment>
+        <translation>Ligar</translation>
+    </message>
+    <message>
+        <source>Name (SSID)</source>
+        <translation>Nome (SSID)</translation>
     </message>
 </context>
 <context>
@@ -66,14 +95,14 @@
         <source>Security Type</source>
         <translation>Tipo de Segurança</translation>
     </message>
-    <message>
-        <source>Band</source>
-        <translation>Banda</translation>
-    </message>
     <message>
         <source>Channel</source>
         <translation>Canal</translation>
     </message>
+    <message>
+        <source>Band</source>
+        <translation>Banda</translation>
+    </message>
     <message>
         <source>Interface</source>
         <translation>Interface</translation>
@@ -240,4 +269,11 @@
         <translation>Definições de rede</translation>
     </message>
 </context>
+<context>
+    <name>dss::module::NetworkModule</name>
+    <message>
+        <source>Wired Connection</source>
+        <translation>Ligação por cabo</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
